==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ClusterVersionStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterVersionStatusFluent<A extends io.fabric8.openshift.api.model.ClusterVersionStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAvailableUpdates(java.lang.Integer index,io.fabric8.openshift.api.model.Release item);
  public A setToAvailableUpdates(java.lang.Integer index,io.fabric8.openshift.api.model.Release item);
  public A addToAvailableUpdates(io.fabric8.openshift.api.model.Release... items);
  public A addAllToAvailableUpdates(java.util.Collection<io.fabric8.openshift.api.model.Release> items);
  public A removeFromAvailableUpdates(io.fabric8.openshift.api.model.Release... items);
  public A removeAllFromAvailableUpdates(java.util.Collection<io.fabric8.openshift.api.model.Release> items);
  public A removeMatchingFromAvailableUpdates(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAvailableUpdates instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.Release> getAvailableUpdates();
  public java.util.List<io.fabric8.openshift.api.model.Release> buildAvailableUpdates();
  public io.fabric8.openshift.api.model.Release buildAvailableUpdate(java.lang.Integer index);
  public io.fabric8.openshift.api.model.Release buildFirstAvailableUpdate();
  public io.fabric8.openshift.api.model.Release buildLastAvailableUpdate();
  public io.fabric8.openshift.api.model.Release buildMatchingAvailableUpdate(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  public java.lang.Boolean hasMatchingAvailableUpdate(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  public A withAvailableUpdates(java.util.List<io.fabric8.openshift.api.model.Release> availableUpdates);
  public A withAvailableUpdates(io.fabric8.openshift.api.model.Release... availableUpdates);
  public java.lang.Boolean hasAvailableUpdates();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> addNewAvailableUpdate();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> addNewAvailableUpdateLike(io.fabric8.openshift.api.model.Release item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> setNewAvailableUpdateLike(java.lang.Integer index,io.fabric8.openshift.api.model.Release item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editAvailableUpdate(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editFirstAvailableUpdate();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editLastAvailableUpdate();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editMatchingAvailableUpdate(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> buildConditions();
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildLastCondition();
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDesired instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.Release getDesired();
  public io.fabric8.openshift.api.model.Release buildDesired();
  public A withDesired(io.fabric8.openshift.api.model.Release desired);
  public java.lang.Boolean hasDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> withNewDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> withNewDesiredLike(io.fabric8.openshift.api.model.Release item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> editDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> editOrNewDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> editOrNewDesiredLike(io.fabric8.openshift.api.model.Release item);
  public A addToHistory(java.lang.Integer index,io.fabric8.openshift.api.model.UpdateHistory item);
  public A setToHistory(java.lang.Integer index,io.fabric8.openshift.api.model.UpdateHistory item);
  public A addToHistory(io.fabric8.openshift.api.model.UpdateHistory... items);
  public A addAllToHistory(java.util.Collection<io.fabric8.openshift.api.model.UpdateHistory> items);
  public A removeFromHistory(io.fabric8.openshift.api.model.UpdateHistory... items);
  public A removeAllFromHistory(java.util.Collection<io.fabric8.openshift.api.model.UpdateHistory> items);
  public A removeMatchingFromHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHistory instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.UpdateHistory> getHistory();
  public java.util.List<io.fabric8.openshift.api.model.UpdateHistory> buildHistory();
  public io.fabric8.openshift.api.model.UpdateHistory buildHistory(java.lang.Integer index);
  public io.fabric8.openshift.api.model.UpdateHistory buildFirstHistory();
  public io.fabric8.openshift.api.model.UpdateHistory buildLastHistory();
  public io.fabric8.openshift.api.model.UpdateHistory buildMatchingHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  public java.lang.Boolean hasMatchingHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  public A withHistory(java.util.List<io.fabric8.openshift.api.model.UpdateHistory> history);
  public A withHistory(io.fabric8.openshift.api.model.UpdateHistory... history);
  public java.lang.Boolean hasHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> addNewHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> addNewHistoryLike(io.fabric8.openshift.api.model.UpdateHistory item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> setNewHistoryLike(java.lang.Integer index,io.fabric8.openshift.api.model.UpdateHistory item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editHistory(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editFirstHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editLastHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editMatchingHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  public java.lang.Long getObservedGeneration();
  public A withObservedGeneration(java.lang.Long observedGeneration);
  public java.lang.Boolean hasObservedGeneration();
  public java.lang.String getVersionHash();
  public A withVersionHash(java.lang.String versionHash);
  public java.lang.Boolean hasVersionHash();
  
  /**
   * Method is deprecated. use withVersionHash instead.
   */
  @java.lang.Deprecated
  public A withNewVersionHash(java.lang.String arg0);
  public interface AvailableUpdatesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ReleaseFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<N>>{
    public N and();
    public N endAvailableUpdate();
    
  }
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ClusterOperatorStatusConditionFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DesiredNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ReleaseFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<N>>{
    public N and();
    public N endDesired();
    
  }
  public interface HistoryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.UpdateHistoryFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<N>>{
    public N and();
    public N endHistory();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ClusterVersionStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterVersionStatusFluent<A extends io.fabric8.openshift.api.model.ClusterVersionStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToAvailableUpdates(java.lang.Integer index,io.fabric8.openshift.api.model.Release item);
  public A setToAvailableUpdates(java.lang.Integer index,io.fabric8.openshift.api.model.Release item);
  public A addToAvailableUpdates(io.fabric8.openshift.api.model.Release... items);
  public A addAllToAvailableUpdates(java.util.Collection<io.fabric8.openshift.api.model.Release> items);
  public A removeFromAvailableUpdates(io.fabric8.openshift.api.model.Release... items);
  public A removeAllFromAvailableUpdates(java.util.Collection<io.fabric8.openshift.api.model.Release> items);
  public A removeMatchingFromAvailableUpdates(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAvailableUpdates instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.Release> getAvailableUpdates();
  public java.util.List<io.fabric8.openshift.api.model.Release> buildAvailableUpdates();
  public io.fabric8.openshift.api.model.Release buildAvailableUpdate(java.lang.Integer index);
  public io.fabric8.openshift.api.model.Release buildFirstAvailableUpdate();
  public io.fabric8.openshift.api.model.Release buildLastAvailableUpdate();
  public io.fabric8.openshift.api.model.Release buildMatchingAvailableUpdate(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  public java.lang.Boolean hasMatchingAvailableUpdate(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  public A withAvailableUpdates(java.util.List<io.fabric8.openshift.api.model.Release> availableUpdates);
  public A withAvailableUpdates(io.fabric8.openshift.api.model.Release... availableUpdates);
  public java.lang.Boolean hasAvailableUpdates();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> addNewAvailableUpdate();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> addNewAvailableUpdateLike(io.fabric8.openshift.api.model.Release item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> setNewAvailableUpdateLike(java.lang.Integer index,io.fabric8.openshift.api.model.Release item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editAvailableUpdate(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editFirstAvailableUpdate();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editLastAvailableUpdate();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<A> editMatchingAvailableUpdate(java.util.function.Predicate<io.fabric8.openshift.api.model.ReleaseBuilder> predicate);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> buildConditions();
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildLastCondition();
  public io.fabric8.openshift.api.model.ClusterOperatorStatusCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.ClusterOperatorStatusCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterOperatorStatusCondition item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterOperatorStatusConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDesired instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.Release getDesired();
  public io.fabric8.openshift.api.model.Release buildDesired();
  public A withDesired(io.fabric8.openshift.api.model.Release desired);
  public java.lang.Boolean hasDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> withNewDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> withNewDesiredLike(io.fabric8.openshift.api.model.Release item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> editDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> editOrNewDesired();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<A> editOrNewDesiredLike(io.fabric8.openshift.api.model.Release item);
  public A addToHistory(java.lang.Integer index,io.fabric8.openshift.api.model.UpdateHistory item);
  public A setToHistory(java.lang.Integer index,io.fabric8.openshift.api.model.UpdateHistory item);
  public A addToHistory(io.fabric8.openshift.api.model.UpdateHistory... items);
  public A addAllToHistory(java.util.Collection<io.fabric8.openshift.api.model.UpdateHistory> items);
  public A removeFromHistory(io.fabric8.openshift.api.model.UpdateHistory... items);
  public A removeAllFromHistory(java.util.Collection<io.fabric8.openshift.api.model.UpdateHistory> items);
  public A removeMatchingFromHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHistory instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.UpdateHistory> getHistory();
  public java.util.List<io.fabric8.openshift.api.model.UpdateHistory> buildHistory();
  public io.fabric8.openshift.api.model.UpdateHistory buildHistory(java.lang.Integer index);
  public io.fabric8.openshift.api.model.UpdateHistory buildFirstHistory();
  public io.fabric8.openshift.api.model.UpdateHistory buildLastHistory();
  public io.fabric8.openshift.api.model.UpdateHistory buildMatchingHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  public java.lang.Boolean hasMatchingHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  public A withHistory(java.util.List<io.fabric8.openshift.api.model.UpdateHistory> history);
  public A withHistory(io.fabric8.openshift.api.model.UpdateHistory... history);
  public java.lang.Boolean hasHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> addNewHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> addNewHistoryLike(io.fabric8.openshift.api.model.UpdateHistory item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> setNewHistoryLike(java.lang.Integer index,io.fabric8.openshift.api.model.UpdateHistory item);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editHistory(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editFirstHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editLastHistory();
  public io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<A> editMatchingHistory(java.util.function.Predicate<io.fabric8.openshift.api.model.UpdateHistoryBuilder> predicate);
  public java.lang.Long getObservedGeneration();
  public A withObservedGeneration(java.lang.Long observedGeneration);
  public java.lang.Boolean hasObservedGeneration();
  public java.lang.String getVersionHash();
  public A withVersionHash(java.lang.String versionHash);
  public java.lang.Boolean hasVersionHash();
  
  /**
   * Method is deprecated. use withVersionHash instead.
   */
  @java.lang.Deprecated
  public A withNewVersionHash(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface AvailableUpdatesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ReleaseFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.AvailableUpdatesNested<N>>{
    public N and();
    public N endAvailableUpdate();
    
  }
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ClusterOperatorStatusConditionFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DesiredNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ReleaseFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.DesiredNested<N>>{
    public N and();
    public N endDesired();
    
  }
  public interface HistoryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.UpdateHistoryFluent<io.fabric8.openshift.api.model.ClusterVersionStatusFluent.HistoryNested<N>>{
    public N and();
    public N endHistory();
    
  }
  
}
